==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/ca.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Emmagatzemament no disponible",
    "Storage invalid" : "Emmagatzemament no vàlid",
    "Unknown error" : "Error desconegut",
    "Could not move %s - File with this name already exists" : "No s'ha pogut moure %s - Ja hi ha un fitxer amb aquest nom",
    "Could not move %s" : " No s'ha pogut moure %s",
    "Permission denied" : "Permís denegat",
    "The target folder has been moved or deleted." : "La carpeta de destí s'ha mogut o eliminat.",
    "The name %s is already used in the folder %s. Please choose a different name." : "El nom %s ja s'usa en la carpeta %s. Indiqueu un nom diferent.",
    "Error when creating the file" : "S'ha produït un error en crear el fitxer",
    "Error when creating the folder" : "S'ha produït un error en crear la carpeta",
    "Unable to set upload directory." : "No es pot establir la carpeta de pujada.",
    "Invalid Token" : "Testimoni no vàlid",
    "No file was uploaded. Unknown error" : "No s'ha carregat cap fitxer. Error desconegut",
    "There is no error, the file uploaded with success" : "No hi ha errors, el fitxer s'ha carregat correctament",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "L’arxiu que voleu carregar supera el màxim definit en la directiva upload_max_filesize del php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
    "The uploaded file was only partially uploaded" : "El fitxer només s'ha carregat parcialment",
    "No file was uploaded" : "No s'ha carregat cap fitxer",
    "Missing a temporary folder" : "Falta un fitxer temporal",
    "Failed to write to disk" : "Ha fallat en escriure al disc",
    "Not enough storage available" : "No hi ha prou espai disponible",
    "Upload failed. Could not find uploaded file" : "La pujada ha fallat. El fitxer pujat no s'ha trobat.",
    "Upload failed. Could not get file info." : "La pujada ha fallat. No s'ha pogut obtenir informació del fitxer.",
    "Invalid directory." : "Directori no vàlid.",
    "Files" : "Fitxers",
    "All files" : "Tots els fitxers",
    "Favorites" : "Preferits",
    "Home" : "Casa",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No es pot pujar {filename} perquè és una carpeta o té 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Mida total del fitxer {size1} excedeix el límit de pujada {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, està carregant {size1} però només pot {size2}",
    "Upload cancelled." : "La pujada s'ha cancel·lat.",
    "Could not get result from server." : "No hi ha resposta del servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Hi ha una pujada en curs. Si abandoneu la pàgina la pujada es cancel·larà.",
    "{new_name} already exists" : "{new_name} ja existeix",
    "Could not create file" : "No s'ha pogut crear el fitxer",
    "Could not create folder" : "No s'ha pogut crear la carpeta",
    "Rename" : "Reanomena",
    "Delete" : "Esborra",
    "Disconnect storage" : "Desonnecta l'emmagatzematge",
    "Unshare" : "Deixa de compartir",
    "No permission to delete" : "Sense permís per esborrar",
    "Download" : "Baixa",
    "Select" : "Selecciona",
    "Pending" : "Pendent",
    "Unable to determine date" : "No s'ha pogut determinar la data",
    "Error moving file." : "Error en moure el fitxer.",
    "Error moving file" : "Error en moure el fitxer",
    "Error" : "Error",
    "Could not rename file" : "No es pot canviar el nom de fitxer",
    "Error deleting file." : "Error en esborrar el fitxer.",
    "No entries in this folder match '{filter}'" : "No hi ha resultats que coincideixin amb '{filter}'",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
    "You don’t have permission to upload or create files here" : "No teniu permisos per a pujar o crear els fitxers aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Pujant %n fitxer","Pujant %n fitxers"],
    "\"{name}\" is an invalid file name." : "\"{name}\" no es un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'emmagatzematge de {owner} està ple, els arxius no es poden actualitzar o sincronitzar més!",
    "Your storage is full, files can not be updated or synced anymore!" : "El vostre espai d'emmagatzemament és ple, els fitxers ja no es poden actualitzar o sincronitzar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Emmagatzematge de {owner} està gairebé ple ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "El vostre espai d'emmagatzemament és gairebé ple ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidències '{filter}'","coincidència '{filter}'"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "Favorited" : "Agregat a favorits",
    "Favorite" : "Preferits",
    "An error occurred while trying to update the tags" : "S'ha produït un error en tractar d'actualitzar les etiquetes",
    "A new file or folder has been <strong>created</strong>" : "S'ha <strong>creat</strong> un nou fitxer o una nova carpeta",
    "A file or folder has been <strong>changed</strong>" : "S'ha <strong>canviat</strong> un fitxer o una carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar les notificacions sobre la creació i canvis dels seus <strong>arxius favorits</strong><em>(solament Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "S'ha <strong>elminiat</strong> un fitxer o una carpeta",
    "A file or folder has been <strong>restored</strong>" : "S'ha <strong>restaurat</strong> un fitxer o una carpeta",
    "You created %1$s" : "Has creat %1$s",
    "%2$s created %1$s" : "%2$s ha creat %1$s",
    "%1$s was created in a public folder" : "Es va crear %1$s en una carpeta pública",
    "You changed %1$s" : "Has canviat %1$s",
    "%2$s changed %1$s" : "%2$s ha canviat %1$s",
    "You deleted %1$s" : "Has esborrat %1$s",
    "%2$s deleted %1$s" : "%2$s ha esborrat %1$s",
    "You restored %1$s" : "Has restaurat %1$s",
    "%2$s restored %1$s" : "%2$s ha restaurat %1$s",
    "%s could not be renamed as it has been deleted" : "No s'ha pogut renombrar %s ja que ha estat borrat",
    "%s could not be renamed" : "%s no es pot canviar el nom",
    "Upload (max. %s)" : "Pujada (màx. %s)",
    "File handling" : "Gestió de fitxers",
    "Maximum upload size" : "Mida màxima de pujada",
    "max. possible: " : "màxim possible:",
    "Save" : "Desa",
    "Can not be edited from here due to insufficient permissions." : "No es pot editar des d'aquí per permisos insuficients.",
    "Settings" : "Arranjament",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Useu aquesta adreça per <a href=\"%s\" target=\"_blank\">accedir als fitxers via WebDAV</a>",
    "New" : "Nou",
    "New text file" : "Nou fitxer de text",
    "Text file" : "Fitxer de text",
    "New folder" : "Carpeta nova",
    "Folder" : "Carpeta",
    "Upload" : "Puja",
    "Cancel upload" : "Cancel·la la pujada",
    "No files in here" : "No hi ha arxius",
    "Upload some content or sync with your devices!" : "Pugi continguts o sincronitzi els seus dispositius.",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Select all" : "Seleccionar tot",
    "Upload too large" : "La pujada és massa gran",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que esteu intentant pujar excedeixen la mida màxima de pujada del servidor",
    "Files are being scanned, please wait." : "S'estan escanejant els fitxers, espereu",
    "Currently scanning" : "Actualment escanejant",
    "No favorites" : "No hi ha favorits",
    "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els arxius i carpetes que vostè marqui com favorits"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/ca.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Emmagatzemament no disponible",
    "Storage invalid" : "Emmagatzemament no vàlid",
    "Unknown error" : "Error desconegut",
    "Unable to set upload directory." : "No es pot establir la carpeta de pujada.",
    "Invalid Token" : "Testimoni no vàlid",
    "No file was uploaded. Unknown error" : "No s'ha carregat cap fitxer. Error desconegut",
    "There is no error, the file uploaded with success" : "No hi ha errors, el fitxer s'ha carregat correctament",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "L’arxiu que voleu carregar supera el màxim definit en la directiva upload_max_filesize del php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
    "The uploaded file was only partially uploaded" : "El fitxer només s'ha carregat parcialment",
    "No file was uploaded" : "No s'ha carregat cap fitxer",
    "Missing a temporary folder" : "Falta un fitxer temporal",
    "Failed to write to disk" : "Ha fallat en escriure al disc",
    "Not enough storage available" : "No hi ha prou espai disponible",
    "The target folder has been moved or deleted." : "La carpeta de destí s'ha mogut o eliminat.",
    "Upload failed. Could not find uploaded file" : "La pujada ha fallat. El fitxer pujat no s'ha trobat.",
    "Upload failed. Could not get file info." : "La pujada ha fallat. No s'ha pogut obtenir informació del fitxer.",
    "Invalid directory." : "Directori no vàlid.",
    "Files" : "Fitxers",
    "All files" : "Tots els fitxers",
    "Favorites" : "Preferits",
    "Home" : "Casa",
    "Close" : "Tanca",
    "Upload cancelled." : "La pujada s'ha cancel·lat.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No es pot pujar {filename} perquè és una carpeta o té 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Mida total del fitxer {size1} excedeix el límit de pujada {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, està carregant {size1} però només pot {size2}",
    "Could not get result from server." : "No hi ha resposta del servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Hi ha una pujada en curs. Si abandoneu la pàgina la pujada es cancel·larà.",
    "Actions" : "Accions",
    "Download" : "Baixa",
    "Rename" : "Reanomena",
    "Delete" : "Esborra",
    "Disconnect storage" : "Desonnecta l'emmagatzematge",
    "Unshare" : "Deixa de compartir",
    "Details" : "Detalls",
    "Select" : "Selecciona",
    "Pending" : "Pendent",
    "Unable to determine date" : "No s'ha pogut determinar la data",
    "No entries in this folder match '{filter}'" : "No hi ha resultats que coincideixin amb '{filter}'",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "No teniu permisos per a pujar o crear els fitxers aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Pujant %n fitxer","Pujant %n fitxers"],
    "New" : "Nou",
    "\"{name}\" is an invalid file name." : "\"{name}\" no es un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'emmagatzematge de {owner} està ple, els arxius no es poden actualitzar o sincronitzar més!",
    "Your storage is full, files can not be updated or synced anymore!" : "El vostre espai d'emmagatzemament és ple, els fitxers ja no es poden actualitzar o sincronitzar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Emmagatzematge de {owner} està gairebé ple ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "El vostre espai d'emmagatzemament és gairebé ple ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidències '{filter}'","coincidència '{filter}'"],
    "Favorited" : "Agregat a favorits",
    "Favorite" : "Preferits",
    "Folder" : "Carpeta",
    "New folder" : "Carpeta nova",
    "Upload" : "Puja",
    "An error occurred while trying to update the tags" : "S'ha produït un error en tractar d'actualitzar les etiquetes",
    "A new file or folder has been <strong>created</strong>" : "S'ha <strong>creat</strong> un nou fitxer o una nova carpeta",
    "A file or folder has been <strong>changed</strong>" : "S'ha <strong>canviat</strong> un fitxer o una carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar les notificacions sobre la creació i canvis dels seus <strong>arxius favorits</strong><em>(solament Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "S'ha <strong>elminiat</strong> un fitxer o una carpeta",
    "A file or folder has been <strong>restored</strong>" : "S'ha <strong>restaurat</strong> un fitxer o una carpeta",
    "You created %1$s" : "Has creat %1$s",
    "%2$s created %1$s" : "%2$s ha creat %1$s",
    "%1$s was created in a public folder" : "Es va crear %1$s en una carpeta pública",
    "You changed %1$s" : "Has canviat %1$s",
    "%2$s changed %1$s" : "%2$s ha canviat %1$s",
    "You deleted %1$s" : "Has esborrat %1$s",
    "%2$s deleted %1$s" : "%2$s ha esborrat %1$s",
    "You restored %1$s" : "Has restaurat %1$s",
    "%2$s restored %1$s" : "%2$s ha restaurat %1$s",
    "Upload (max. %s)" : "Pujada (màx. %s)",
    "File handling" : "Gestió de fitxers",
    "Maximum upload size" : "Mida màxima de pujada",
    "max. possible: " : "màxim possible:",
    "Save" : "Desa",
    "Settings" : "Arranjament",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Useu aquesta adreça per <a href=\"%s\" target=\"_blank\">accedir als fitxers via WebDAV</a>",
    "Cancel upload" : "Cancel·la la pujada",
    "No files in here" : "No hi ha arxius",
    "Upload some content or sync with your devices!" : "Pugi continguts o sincronitzi els seus dispositius.",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Select all" : "Seleccionar tot",
    "Upload too large" : "La pujada és massa gran",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que esteu intentant pujar excedeixen la mida màxima de pujada del servidor",
    "No favorites" : "No hi ha favorits",
    "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els arxius i carpetes que vostè marqui com favorits",
    "Text file" : "Fitxer de text",
    "You changed %1$s" : "Has canviat %1$s",
    "You created %1$s" : "Has creat %1$s",
    "You deleted %1$s" : "Has esborrat %1$s",
    "You restored %1$s" : "Has restaurat %1$s"
},
"nplurals=2; plural=(n != 1);");
